#include <iostream>
#include <fstream>
#include <sstream>
#include <set>
#include <map>

////////////////////////////////////////////////////////////////////////////////
// GRAPH

struct edge_t
{
  const unsigned int u;
  const unsigned int v;
  const unsigned int c;

  // constructor
  edge_t(unsigned int U, unsigned int V, unsigned int C) : u(U), v(V), c(C) {}

  // sort by increasing weight for maximum spanning tree
  bool operator<(const edge_t &o) const
  {
    if (c == o.c)
    {
      if (u == o.u)
        return v < o.v;
      else
        return u < o.u;
    }
    else
      return c > o.c;
  }
};

typedef std::set<edge_t> edge_set_t;

////////////////////////////////////////////////////////////////////////////////
// UNION-FIND
std::map<int, std::pair<int, unsigned int> > Sets;  // map to parent & rank

void MakeSet(int x) {
  Sets.insert(std::make_pair(x, std::make_pair(x, 0)));
}

int Find(int x) {
  if (Sets[x].first == x) return x;              // Parent == x ?
  else return Sets[x].first = Find(Sets[x].first);  // Get Parent
}

void Union(int x, int y) {
  int parentX = Find(x), parentY = Find(y);
  int rankX = Sets[parentX].second, rankY = Sets[parentY].second;
  if (parentX == parentY) return;
  else if (rankX < rankY)
    Sets[parentX].first = parentY;
  else
    Sets[parentY].first = parentX;
  if (rankX == rankY)
    Sets[parentX].second++;
}

////////////////////////////////////////////////////////////////////////////////
// Debug handling

// enable DOT dumps of test cases.
bool dump = false;
unsigned int dot_id = 0;

void dot_dump(const edge_set_t &mst, edge_set_t &edges)
{
  dot_id++;

  std::stringstream tmp;
  tmp << "test_case-" << dot_id << ".dot";

  std::ofstream d(tmp.str());

  d << "graph mst {\n";

  for(const edge_t &e : mst)
  {
    d << "  " << e.u << " -- " << e.v << "[label=" << e.c << " color=red constraint=false];\n";
    edges.erase(e);
  }

  for(const edge_t &e : edges)
  {
    d << "  " << e.u << " -- " << e.v << "[label=" << e.c << "];\n";
  }

  d << "}\n";
}

////////////////////////////////////////////////////////////////////////////////
// Test case handling

//handle a single test case
void test_case()
{
  // read number of nodes and edges
  unsigned int nodes, edges;
  std::cin >> nodes >> edges;

  // clean up from previous test case.
  edge_set_t Edges;
  Sets.clear();

  // read input edges with weights
  for(unsigned int e = 0; e < edges; e++)
  {
    // read edges
    int u, v, c;
    std::cin >> u >> v >> c;

    // append edge
    Edges.emplace(u, v, c);
  }

  // UNION-FIND initialization
  for(unsigned int n = 1; n <= nodes; n++)
    MakeSet(n);

  // KRUSKAL
  edge_set_t MST = Edges;            // inverse of final maximum spanning tree

  for(auto e : Edges) {
    if (Find(e.u) != Find(e.v)) {
      Union(e.u, e.v);       // update Union-Find
      MST.erase(e);          // include edge in MST, i.e., exclude form solution
    }
  }

  // compute final cost
  unsigned int total_cost = 0;
  for(const edge_t &e : MST)
  {
    total_cost += e.c;
  }

  if (dump)
    dot_dump(MST, Edges);

  // print final result
  std::cout << total_cost << "\n";
}

int main(int argc, char **argv)
{
  if (argc != 1)
    dump = true;

  // handle each test case
  unsigned int num_test_cases;
  std::cin >> num_test_cases;
  for(unsigned int i = 0; i < num_test_cases; i++)
  {
    test_case();
  }
}
